# coding: utf-8
#
# GIL limit python multi-thread effectiveness.
# But is seems fine, because these operation have so many socket IO
# So  it seems no need to use multiprocess
#
import uiautomator2 as u2
import adbutils
import threading
from logzero import logger


def worker(d: u2.Device):
    d.app_start("io.appium.android.apis", stop=True)
    d(text="App").wait()
    for el in d.xpath("@android:id/list").child("/android.widget.TextView").all():
        logger.info("%s click %s", d.serial, el.text)
        el.click()
        d.press("back")
    logger.info("%s DONE", d.serial)


for dev in adbutils.adb.device_list():
    print("Dev:", dev)
    d = u2.connect(dev.serial)
    t = threading.Thread(target=worker, args=(d,))
    t.start()



# coding: utf-8
#

import time
import uiautomator2 as u2


def test_swipe_duration(d: u2.Device):
    w, h = d.window_size()
    start = time.time()
    d.debug = True
    d.swipe(w//2, h//2, w-1, h//2, 2.0)
    duration = time.time() - start
    assert duration >= 1.5 # actually duration is about 7s in my TT



# coding: utf-8
#

import uiautomator2 as u2


def test_watch_context(sess: u2.Device):
    with sess.watch_context(builtin=True) as ctx:
        ctx.when("App").click()
        
        sess(text='Menu').click()
        assert sess(text='Inflate from XML').wait()


def teardown_function(d: u2.Device):
    print("Teardown", d)
